RegistryCache

Struct RegistryCache 

pub struct RegistryCache { /* private fields */ }
Used to cache IBC path data from the chain registry for easy filtering.

Implementations

Source

impl RegistryCache

pub async fn get_path( &self, chain_a: &str, chain_b: &str, ) -> Result<Option<IBCPath>, Report>

Returns a cached IBCPath representing a channel between chain_a and chain_b if it exists. Passing in the same value for chain_a and chain_b will always return Ok(None).

Arguments
  • chain_a - A chain name. Must match a directory name in the root of the chain registry repository <https://github.com/cosmos/chain-registry>
  • chain_b - A chain name. Must match a directory name in the root of the chain registry repository <https://github.com/cosmos/chain-registry>
pub async fn get_paths_filtered(&self, tag: Tag) -> Result<Vec<IBCPath>, Report>

Returns cached IBCPath that match a provided Tag

Arguments
  • tag - A Tag representing the the desired key/value pair to filter by.
Examples
use chain_registry::cache::{RegistryCache, Tag};

// store paths from the registry repository in a cache
let cache = RegistryCache::try_new().await?;
let dex = "osmosis".to_string();

// paths will contain a vec of all IBC paths containing the tag dex:osmosis
let paths = cache.get_paths_filtered(Tag::Dex(dex))?;
pub async fn try_new() -> Result<RegistryCache, Report>

Creates a new cache by retrieving and deserializing each IBCPath from the Cosmos Chain Registry for easy filtering